@@ -1,5 +1,12 @@
 """Dynamics Web API Client."""
 
+from .apply_functions import apl
 from .client import DynamicsClient
 from .query_functions import ftr
-from .apply_functions import apl
+
+
+__all__ = [
+    "DynamicsClient",
+    "ftr",
+    "apl",
+]
