@@ -2,21 +2,27 @@ import logging
 
 from . import status
 
+
 try:
     from rest_framework.exceptions import APIException
 
 except ImportError:
+
     class APIException(Exception):
         status_code = status.HTTP_500_INTERNAL_SERVER_ERROR
         default_detail = "A server error occurred."
         default_code = "error"
 
-        def __init__(self, detail: str = None):
+        def __init__(self, detail: str = None, code=None):
             if detail is None:
                 detail = self.default_detail
 
-            self.detail = f"[{self.status_code}] {detail}"
+            if code is None:
+                code = self.default_code
+
+            self.detail = f"[{self.status_code}] {detail} <{code}>"
             logger.error(self.detail)
+            super().__init__(detail)
 
         def __str__(self):
             return str(self.detail)
@@ -45,9 +51,6 @@ class DynamicsException(APIException):
     default_detail = "Dynamics Web API call failed."
     default_code = "dynamics_link_failed"
 
-    def __init__(self, detail=None, code=None, *arg, **kwargs):
-        super(DynamicsException, self).__init__(detail, code)
-
 
 class ParseError(DynamicsException):
     status_code = status.HTTP_400_BAD_REQUEST
@@ -75,14 +78,9 @@ class NotFound(DynamicsException):
 
 class MethodNotAllowed(DynamicsException):
     status_code = status.HTTP_405_METHOD_NOT_ALLOWED
-    default_detail = 'Method "{method}" not allowed.'
+    default_detail = "Method not allowed."
     default_code = "dynamics_method_not_allowed"
 
-    def __init__(self, method: str, detail=None, code=None):
-        if detail is None:
-            self.default_detail = self.default_detail.format(method=method)
-        super().__init__(detail=detail, code=code)
-
 
 class DuplicateRecordError(DynamicsException):
     # Could also be a concurrency mismatch, but this is much more common
@@ -98,19 +96,20 @@ class PayloadTooLarge(DynamicsException):
 
 
 class APILimitsExceeded(DynamicsException):
-    """Error when API protection limits are exceeded."""
+    """Error when API protection limits are exceeded.
 
-    # Dynamics Web API service protection limits were exceeded.
-    # This can be due to any of the following reasons:
-    #
-    # 1. Over 6000 requests within a 5 minute sliding window.
-    # 2. Combined request execution time exceeded 20 minutes within a 5 minute sliding window.
-    # 3. Over 52 concurrent request.
-    # 4. Maximum number of API requests per 24 hours exceeded (depends on Dynamics licence).
-    #
-    # You can read more here:
-    # https://docs.microsoft.com/en-us/powerapps/developer/data-platform/api-limits
-    # https://docs.microsoft.com/en-us/power-platform/admin/api-request-limits-allocations
+    Dynamics Web API service protection limits were exceeded.
+    This can be due to any of the following reasons:
+
+    1. Over 6000 requests within a 5 minute sliding window.
+    2. Combined request execution time exceeded 20 minutes within a 5 minute sliding window.
+    3. Over 52 concurrent request.
+    4. Maximum number of API requests per 24 hours exceeded (depends on Dynamics licence).
+
+    You can read more here:
+    https://docs.microsoft.com/en-us/powerapps/developer/data-platform/api-limits
+    https://docs.microsoft.com/en-us/power-platform/admin/api-request-limits-allocations
+    """
 
     status_code = status.HTTP_429_TOO_MANY_REQUESTS
     default_detail = "Dynamics Web API limits were exceeded."
